#include "itext.h"


char * euc2utf8(iconv_t con,char *str,int len)
{
	char *euc,*utf8,*utf;
	int euc_len,utf8_len;

	euc_len = len;

	euc = (char *)malloc(euc_len + 1);
	memcpy(euc,str,len);

	utf8_len = len * 2;
	utf8 = (char *)malloc(utf8_len);
	memset(utf8,0,utf8_len);

	utf = utf8;
	iconv(con,&euc,&euc_len,&utf8,&utf8_len);


	return utf;
}



